@@ -41,6 +41,12 @@ def is_bspfile(filename):
     """Quickly see if a file is a bsp file by checking the magic number.
 
     The filename argument may be a file for file-like object.
+
+    Args:
+        filename: File to check as string or file-like object.
+
+    Returns:
+        True if given file's magic number is correct.
     """
     try:
         if hasattr(filename, 'read'):
@@ -278,12 +284,13 @@ class Plane:
         distance: The distance from world (0, 0, 0) to a point on the plane
 
         type: Planes are classified as follows:
-            0: Axial plane aligned to the x-axis.
-            1: Axial plane aligned to the y-axis.
-            2: Axial plane aligned to the z-axis.
-            3: Non-axial plane roughly aligned to the x-axis.
-            4: Non-axial plane roughly aligned to the y-axis.
-            5: Non-axial plane roughly aligned to the z-axis.
+
+            0. Axial plane aligned to the x-axis.
+            1. Axial plane aligned to the y-axis.
+            2. Axial plane aligned to the z-axis.
+            3. Non-axial plane roughly aligned to the x-axis.
+            4. Non-axial plane roughly aligned to the y-axis.
+            5. Non-axial plane roughly aligned to the z-axis.
     """
 
     format = '<4fi'
@@ -301,6 +308,7 @@ class Plane:
                  normal_z,
                  distance,
                  type):
+        """Constructs a Plane object."""
 
         self.normal = normal_x, normal_y, normal_z
         self.distance = distance
@@ -336,10 +344,12 @@ class Miptexture:
         name: The name of the miptexture.
 
         width: The width of the miptexture.
-            Note: this is the width at mipmap level 0.
+            Note:
+                This is the width at mipmap level 0.
 
         height: The height of the miptexture.
-            Note: this is the height at mipmap level 0.
+            Note:
+                This is the height at mipmap level 0.
 
         offsets: The offsets for each of the mipmaps. This is a tuple of size
             four (this is the number of mipmap levels).
@@ -347,13 +357,14 @@ class Miptexture:
         pixels: A tuple of unstructured pixel data represented as integers. A
             palette must be used to obtain RGB data.
 
-            Note: this is the pixel data for all four mip levels. The size is
-            calculated using the simplified form of the geometric series where
-            r = 1/4 and n = 4.
+            Note:
+                This is the pixel data for all four mip levels. The size is
+                calculated using the simplified form of the geometric series where
+                r = 1/4 and n = 4.
 
             The size of this tuple is:
 
-            miptexture.width * miptexture.height * 85 / 64
+                miptexture.width * miptexture.height * 85 / 64
     """
 
     format = '<16s6I'
@@ -368,6 +379,8 @@ class Miptexture:
     )
 
     def __init__(self):
+        """Constructs a MipTexture object."""
+
         self.name = None
         self.width = None
         self.height = None
@@ -433,6 +446,8 @@ class Vertex:
     )
 
     def __init__(self, x, y, z):
+        """Constructs a Vertex object."""
+
         self.x = x
         self.y = y
         self.z = z
@@ -471,9 +486,11 @@ class Node:
         children: A two-tuple of the two sub-spaces formed by the partitioning
             plane.
 
-            Note: Child 0 is the front sub-space, and 1 is the back sub-space.
+            Note:
+                Child 0 is the front sub-space, and 1 is the back sub-space.
 
-            Note: If bit 15 is set, the child is a leaf.
+            Note:
+                If bit 15 is set, the child is a leaf.
 
         bounding_box_min: The minimum coordinate of the bounding box containing
             this node and all of its children.
@@ -512,6 +529,7 @@ class Node:
                  bounding_box_max_z,
                  first_face,
                  number_of_faces):
+        """Constructs a Node object."""
 
         self.plane_number = plane_number
         self.children = child_front, child_back
@@ -582,6 +600,7 @@ class TextureInfo:
                  t_offset,
                  miptexture_number,
                  flags):
+        """Constructs a TextureInfo object"""
 
         self.s = s_x, s_y, s_z
         self.s_offset = s_offset
@@ -658,6 +677,7 @@ class Face:
                  style_2,
                  style_3,
                  light_offset):
+        """Constructs a Face object."""
 
         self.plane_number = plane_number
         self.side = side
@@ -699,7 +719,8 @@ class ClipNode:
         children: A two-tuple of the two sub-spaces formed by the partitioning
             plane.
 
-            Note: Child 0 is the front sub-space, and 1 is the back sub-space.
+            Note:
+                Child 0 is the front sub-space, and 1 is the back sub-space.
     """
 
     format = '<i2h'
@@ -714,6 +735,7 @@ class ClipNode:
                  plane_number,
                  child_front,
                  child_back):
+        """Constructs a ClipNode object."""
 
         self.plane_number = plane_number
         self.children = child_front, child_back
@@ -801,6 +823,7 @@ class Leaf:
                  ambient_level_1,
                  ambient_level_2,
                  ambient_level_3):
+        """Constructs a Leaf object."""
 
         self.contents = contents
         self.visibilitiy_offset = visibilitiy_offset
@@ -849,6 +872,8 @@ class Edge:
     )
 
     def __init__(self, vertex_0, vertex_1):
+        """Constructs an Edge object."""
+
         self.vertexes = vertex_0, vertex_1
 
     def __getitem__(self, item):
@@ -921,6 +946,7 @@ class Model:
                  visleafs,
                  first_face,
                  number_of_faces):
+        """Constructs a Model object."""
 
         self.bounding_box_min = bounding_box_min_x, bounding_box_min_y, bounding_box_min_z
         self.bounding_box_max = bounding_box_max_x, bounding_box_max_y, bounding_box_max_z
@@ -1053,27 +1079,29 @@ class _SurfEdges:
     """Helper class for working with the surfedges lump"""
     @staticmethod
     def write(file, surfedges):
-        file.write(surfedges)
+        data = struct.pack(f'<{len(surfedges)}i', *surfedges)
+        file.write(data)
 
     @staticmethod
     def read(file, size=-1):
-        return file.read(size)
+        data = file.read(size)
+        return struct.unpack(f'<{len(data) // 4}i', data)
 
 
 class Mesh:
     """Class for representing mesh data
 
     Attributes:
-        vertices: A list of vertex data represented as XYZ three-tuples.
+        vertices: A sequence of vertex data represented as XYZ three-tuples.
 
-        triangles: A list of triangle data represented by a three-tuple of
+        triangles: A sequence of triangle data represented by a three-tuple of
             vertex indexes.
 
-        uvs: A list of uv coordinates represented as UV tuples.
+        uvs: A sequence of uv coordinates represented as UV tuples.
 
-        normals: A list of vertex normal data represented as XYZ three-tuples.
+        normals: A sequence of vertex normal data represented as XYZ three-tuples.
 
-        sub_meshes: A list of triangle index lists.
+        sub_meshes: A sequence of triangle index lists.
     """
 
     __slots = (
@@ -1127,44 +1155,48 @@ class Bsp(ReadWriteFile):
     """Class for working with Bsp files
 
     Example:
-        b = Bsp.open(file)
+        Basic usage::
+
+            from vgio.quake.bsp.bsp29 import Bsp
+            b = Bsp.open('e1m1.bsp')
 
     Attributes:
         version: Version of the map file. Vanilla Quake is 29.
 
         entities: A string containing the entity definitions.
 
-        planes: A list of Planes used by the bsp tree data structure.
+        planes: A sequence of Planes used by the bsp tree data structure.
 
-        miptextures: A list of Miptextures.
+        miptextures: A sequence of Miptextures.
 
-        vertexes: A list of Vertexes.
+        vertexes: A sequence of Vertexes.
 
-        visibilities: A list of ints representing visibility data.
+        visibilities: A sequence of ints representing visibility data.
 
-        nodes: A list of Nodes used by the bsp tree data structure.
+        nodes: A sequence of Nodes used by the bsp tree data structure.
 
-        texture_infos: A list of TextureInfo objects.
+        texture_infos: A sequence of TextureInfo objects.
 
-        faces: A list of Faces.
+        faces: A sequence of Faces.
 
-        lighting: A list of ints representing lighting data.
+        lighting: A sequence of ints representing lighting data.
 
-        clip_nodes: A list of ClipNodes used by the bsp tree data structure.
+        clip_nodes: A sequence of ClipNodes used by the bsp tree data structure.
 
-        leafs: A list of Leafs used by the bsp tree data structure.
+        leafs: A sequence of Leafs used by the bsp tree data structure.
 
-        mark_surfaces: A list of ints representing lists of consecutive faces
+        mark_surfaces: A sequence of ints representing lists of consecutive faces
             used by the Node objects.
 
-        edges: A list of Edges.
+        edges: A sequence of Edges.
 
-        surf_edges: A list of ints representing  list of consecutive edges used
+        surf_edges: A sequence of ints representing  list of consecutive edges used
             by the Face objects.
 
-        models: A list of Models.
+        models: A sequence of Models.
 
-            Note: The first model is the entire level.
+            Note:
+                The first model is the entire level.
 
         fp: The file-like object to read data from.
 
@@ -1413,7 +1445,8 @@ class Bsp(ReadWriteFile):
         Returns:
             An Image object or None.
 
-            Note: Not all indices are valid miptextures.
+            Note:
+                Not all indices are valid miptextures.
         """
 
         if index > len(self.miptextures):
